@@ -1,6 +1,7 @@
 """Prasopes init"""
 from . import config
 from . import datatools
+from . import datasets
 from . import docks
 from . import drltools
 from . import filetools
@@ -13,9 +14,10 @@ from . import zcetools_help
 from . import reactivitytools
 
 
-__version__ = "0.0.37"
+__version__ = "0.0.40"
 
 
-__all__ = ['config', 'datatools', 'docks', 'drltools', 'drltoos_gui', 'filetools',
-           'graphtools', 'imagetools', 'predictmz', 'tangoicons', 'zcetools',
-           'zcetools_help', 'reactivitytools']
+__all__ = ['config', 'datatools', 'docks', 'drltools', 'datasets',
+           'drltoos_gui', 'filetools', 'graphtools', 'imagetools',
+           'predictmz', 'tangoicons', 'zcetools', 'zcetools_help',
+           'reactivitytools']
