@@ -4,18 +4,15 @@ from PyQt5 import QtCore
 from PyQt5 import QtWidgets
 from PyQt5 import QtGui
 from PyQt5 import QtPrintSupport
-from rawprasslib import load_raw
 from prasopes.predictmz import predict as getmzpattern
 from pathlib import Path
 try:
-    from rawautoparams import load_params
     import rawautoparams
     autoparams = True
 except ImportError:
     autoparams = False
 import copy
 import rawprasslib
-import numpy as np
 import prasopes.config as cf
 import prasopes.datatools as dt
 import prasopes.drltools_gui as drlgui
@@ -25,7 +22,7 @@ import prasopes.imagetools as imgt
 import prasopes.zcetools as zce
 import prasopes.docks as docks
 import prasopes.datasets as datasets
-import prasopes.toftools as tt
+import prasopes.mobtools as mt
 import prasopes.tangoicons
 import sys
 import logging
@@ -55,7 +52,7 @@ def show_exception_and_exit(exc_type, exc_value, tb):
     traceback.print_exception(exc_type, exc_value, tb)
     details = "\n".join(traceback.format_exception(exc_type, exc_value, tb))
     errmsg = "\n".join(traceback.format_exception_only(exc_type, exc_value))\
-            + ("\n The program might misbehave, do you want to continue?")
+        + ("\n The program might misbehave, do you want to continue?")
     msgbox = QtWidgets.QMessageBox(
         3, "Exception!", errmsg,
         QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
@@ -69,7 +66,7 @@ def load_file(parent, augCanvas, update, settings, loadthread, filename=None,
               nothreading=False):
     """populates dataset and plots it"""
     directory = augCanvas.ds.filename if augCanvas.ds\
-                else settings.value("open_folder")
+        else settings.value("open_folder")
     filename = filename or QtWidgets.QFileDialog.getOpenFileName(
             caption="Open spectrum", directory=directory,
             filter="All supported formats (*.raw *.RAW *.d);;"
@@ -199,7 +196,7 @@ def oddeven_changed(augCanvas, config, oddevenact):
 
 
 def legendvis_changed(augCanvas, config, legendact):
-    config.setValue("view/legend",legendact.isChecked())
+    config.setValue("view/legend", legendact.isChecked())
     if augCanvas.chromplot.get_legend():
         for ax in (augCanvas.spectplot, augCanvas.chromplot):
             ax.get_legend().set_visible(config.value("view/legend", type=bool))
@@ -218,7 +215,7 @@ def paint_override(self, augCanvas):
                          self.conftype.format("onlymanann"), type=bool)))
             for i, line in enumerate(data)]
         legend = 1
-        if legend == True:
+        if legend:
             self.plot.legend(loc=2)
     else:
         [gt.pop_plot(*line, self.plot, texts, i)
@@ -253,7 +250,7 @@ def key_pressed(event, augCanvas, config, update):
 def about(parent):
     """constructs window with "about" info"""
     rawparver = rawautoparams.__version__ if autoparams else\
-            "library not found"
+        "library not found"
 
     QtWidgets.QMessageBox.information(
             parent, "About Prasopes",
@@ -353,7 +350,7 @@ def main():
     tofact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
         "applications-utilities"), "TO&F...", None)
     tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_F)
-    tofact.triggered.connect(lambda: tt.main_window(
+    tofact.triggered.connect(lambda: mt.main_window(
         main_window, augCanvas, update))
     aboutact = QtWidgets.QAction("&About Prasopes", None)
     aboutact.triggered.connect(lambda: about(main_window))
