@@ -35,6 +35,7 @@ class AugFigureCanvas(FigureCanvas):
             timesarg=[])
         self.drlcache = [None, None]
         self.tofcache = [None, None]
+        self.mobontofcache = [None, None]
         grid = self.figure.add_gridspec(2, 1)
         self.chromplot = self.figure.add_subplot(grid[0, 0],
                                                  facecolor=(1, 1, 1, 0.8))
@@ -125,7 +126,7 @@ class AugSpanSelector(SpanSelector):
 class FixedScalarFormatter(matplotlib.ticker.ScalarFormatter):
     def __init__(self):
         super().__init__()
-        self._powerlimits = (0,0)
+        self._powerlimits = (0, 0)
 
     def _set_format(self):
         """_set_format override"""
@@ -243,9 +244,9 @@ def plot_subtime(augCanvas):
     for i, args in enumerate(chromargs):
         if len(args):
             dots_x, dots_y = [augCanvas.ds.chromatograms[i][j][args]
-                              for j in (0,1)]
+                              for j in (0, 1)]
             augCanvas.chromplot.plot(dots_x, dots_y, '.', color=(
-            colors[i % len(colors)]/255))
+                                     colors[i % len(colors)]/255))
 
     augCanvas.spectplot.set_xlim(slims[0])
     if not cf.settings().value("view/autozoomy", type=bool):
@@ -308,8 +309,8 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
     """annotate spectrum
 
     First define the array, in which the annotation should occur.
-    Then remove values which are invalid as local maximas. Local maximas are then
-    reduced to a representation of the important ones by the sub_peaks
+    Then remove values which are invalid as local maximas. Local maximas are
+    then reduced to a representation of the important ones by the sub_peaks
     function"""
 
     def sub_peaks(peakz, hardpeaks, xrange, yrange, coef_x=15, coef_y=20):
@@ -334,12 +335,13 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
         # Thanks to:
         # https://gist.github.com/ben741/d8c70b608d96d9f7ed231086b237ba6b
         minlim = ms_spec.get_ylim()[1] * ann_limit
-        lims = [*ms_spec.get_xlim(),*ms_spec.get_ylim()]
+        lims = [*ms_spec.get_xlim(), *ms_spec.get_ylim()]
         maxargs = np.where((xdata[1:-1] > lims[0]) & (xdata[1:-1] < lims[1]) &
                            (ydata[1:-1] > minlim) & (ydata[1:-1] < lims[3]) &
                            (ydata[1:-1] > ydata[0:-2]) &
                            (ydata[1:-1] > ydata[2:]))[0] + 1
-        peakline = np.empty([len(maxargs)], dtype=[('x', np.float32), ('y', np.float32)])
+        peakline = np.empty([len(maxargs)], dtype=[('x', np.float32),
+                                                   ('y', np.float32)])
         peakline['x'], peakline['y'] = xdata[maxargs], ydata[maxargs]
         peaks.append(peakline)
 
@@ -359,15 +361,17 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
 
     dispints = cf.settings().value("view/intensities", type=bool)
     for peak in s_peaks:
-        annotation = '{0:.2f}\n{1: .2e}'.format(peak[0], peak[1])\
-                if dispints else '{0:.2f}'.format(peak[0])
+        digits = cf.settings().value("view/digits", type=int)
+        annotation = '{0:.{2}f}\n{1: .{2}e}'.format(peak[0], peak[1], digits)\
+                if dispints else '{0:.{1}f}'.format(peak[0], digits)
         peaktext = ms_spec.annotate(
             annotation, xy=(peak['x'], peak['y']), textcoords='data',
             picker=True, in_layout=False)
         msdata['annotation'].append(peaktext)
 
 
-def pop_plot(xdata, ydata, plot, plot_data, colornum=0, legend=None, annotate=True):
+def pop_plot(xdata, ydata, plot, plot_data, colornum=0,
+             legend=None, annotate=True):
     """Define and populate plot"""
     if len(xdata):
         plot.plot(xdata, ydata, linewidth=1, color=(
@@ -384,8 +388,8 @@ def pop_plot(xdata, ydata, plot, plot_data, colornum=0, legend=None, annotate=Tr
         plot_data['texts'] = [plot.annotate(
             a.get_text(), a.xy, picker=True, bbox=ann_bbox, in_layout=False)
             for a in plot_data['texts']]
-    if "annotation" in plot_data and annotate == True:
-            ann_spec(plot, plot_data)
+    if "annotation" in plot_data and annotate:
+        ann_spec(plot, plot_data)
     if "xtics" in plot_data:
         plot.locator_params(nbins=plot_data["xtics"], axis='x')
         plot.minorticks_on()
@@ -456,9 +460,10 @@ def populate(augCanvas):
             legend = legendize(augCanvas.ds.headers[i], augCanvas)
         else:
             legend = None
-        pop_plot(msxy[i][0], msxy[i][1], augCanvas.spectplot, augCanvas.ms, i, legend)
+        pop_plot(msxy[i][0], msxy[i][1], augCanvas.spectplot,
+                 augCanvas.ms, i, legend)
         pop_plot(chromxy[i][0], chromxy[i][1], augCanvas.chromplot,
-                augCanvas.chrom, i, legend)
+                 augCanvas.chrom, i, legend)
     for ax in (augCanvas.spectplot, augCanvas.chromplot):
         if augCanvas.ds.headers:
             ax.legend(loc=2)
